AbstractTwitterClient class abstract

An abstraction to make http calls to the Twitter API used by the services.

Implemented by TwitterClient.

Implementers

Constructors

AbstractTwitterClient()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(Uri uri, {Map<String, String>? headers, Duration? timeout}) → Future<Response>
multipartRequest(Uri uri, {List<MultipartFile>? files, Map<String, String>? headers, Duration? timeout}) → Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(Uri uri, {Map<String, String>? headers, dynamic body, Encoding? encoding, Duration? timeout}) → Future<Response>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited