InitialInfo class

Annotations
  • @JsonSerializable.new(explicitToJson: true, fieldRename: FieldRename.snake)

Constructors

InitialInfo()
InitialInfo.fromJson(Map<String, dynamic> json)
factory

Properties

editableUntilMsecs ↔ String?
getter/setter pair
editsRemaining ↔ String?
getter/setter pair
editTweetIds ↔ List<String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isEditEligible ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited