Entities class

Annotations
  • @JsonSerializable.new(explicitToJson: true, fieldRename: FieldRename.snake)

Constructors

Entities()
Entities.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hashtags ↔ List<Hashtag>?
Represents hashtags which have been parsed out of the Tweet text.
getter/setter pair
media ↔ List<Media>?
Represents media elements uploaded with the Tweet.
getter/setter pair
polls ↔ List<Poll>?
Represents Twitter Polls included in the Tweet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbols ↔ List<Symbol>?
Represents symbols, i.e. $cashtags, included in the text of the Tweet.
getter/setter pair
urls ↔ List<Url>?
Represents URLs included in the text of a Tweet.
getter/setter pair
userMentions ↔ List<UserMention>?
Represents URLs included in the text of a Tweet.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited