Url class

Annotations
  • @JsonSerializable.new(explicitToJson: true, fieldRename: FieldRename.snake)

Constructors

Url()
Url.fromJson(Map<String, dynamic> json)
factory

Properties

displayUrl ↔ String?
URL pasted/typed into Tweet.
getter/setter pair
expandedUrl ↔ String?
Expanded version of display_url.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
indices ↔ List<int>?
An array of integers representing offsets within the Tweet text where the URL begins and ends. The first integer represents the location of the first character of the URL in the Tweet text. The second integer represents the location of the first non-URL character after the end of the URL.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
Wrapped URL, corresponding to the value embedded directly into the raw Tweet text, and the values for the indices parameter.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited