Place class

Annotations
  • @JsonSerializable.new(explicitToJson: true, fieldRename: FieldRename.snake)

Constructors

Place()
Place.fromJson(Map<String, dynamic> json)
factory

Properties

boundingBox ↔ BoundingBox?
A bounding box of coordinates which encloses this place.
getter/setter pair
country ↔ String?
Name of the country containing this place.
getter/setter pair
countryCode ↔ String?
Shortened country code representing the country containing this place.
getter/setter pair
fullName ↔ String?
Full human-readable representation of the place’s name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID representing this place. Note that this is represented as a string, not an integer.
getter/setter pair
name ↔ String?
Short human-readable representation of the place’s name.
getter/setter pair
placeType ↔ String?
The type of location represented by this place.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
URL representing the location of additional place metadata for this place.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited