TwitterList class

Annotations
  • @JsonSerializable.new(explicitToJson: true, fieldRename: FieldRename.snake)

Constructors

TwitterList()
TwitterList.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt ↔ DateTime?
getter/setter pair
description ↔ String?
getter/setter pair
following ↔ bool?
getter/setter pair
fullName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idStr ↔ String?
getter/setter pair
memberCount ↔ int?
getter/setter pair
mode ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slug ↔ String?
getter/setter pair
subscriberCount ↔ int?
getter/setter pair
uri ↔ String?
getter/setter pair
user ↔ User?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited