ProcessingInfo class

Annotations
  • @JsonSerializable.new(explicitToJson: true, fieldRename: FieldRename.snake)

Constructors

ProcessingInfo()
ProcessingInfo.fromJson(Map<String, dynamic> json)
factory

Properties

checkAfterSecs ↔ int?
getter/setter pair
failed → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
inProgress → bool
no setter
pending → bool
no setter
progressPercent ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
getter/setter pair
succeeded → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited