UploadFinalize class

Annotations
  • @JsonSerializable.new(explicitToJson: true, fieldRename: FieldRename.snake)

Constructors

UploadFinalize()
UploadFinalize.fromJson(Map<String, dynamic> json)
factory

Properties

expiresAfterSecs ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mediaIdString ↔ String?
getter/setter pair
processingInfo ↔ ProcessingInfo?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited