TrendLocation class

The trends/place response only contains name and woeid in its TrendLocations.

For whatever reason the response keys are not in snake_case, and the id in parentid is not capitalized.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

TrendLocation()
TrendLocation.fromJson(Map<String, dynamic> json)
factory

Properties

country ↔ String?
getter/setter pair
countryCode ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
parentid ↔ int?
getter/setter pair
placeType ↔ PlaceType?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
getter/setter pair
woeid ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited