BannerSizes class

Annotations
  • @JsonSerializable.new(explicitToJson: true, fieldRename: FieldRename.snake)

Constructors

BannerSizes()
BannerSizes.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipad ↔ BannerSize?
getter/setter pair
ipadRetina ↔ BannerSize?
getter/setter pair
mobile ↔ BannerSize?
getter/setter pair
mobileRetina ↔ BannerSize?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size1500x500 ↔ BannerSize?
getter/setter pair
size300x100 ↔ BannerSize?
getter/setter pair
size600x200 ↔ BannerSize?
getter/setter pair
web ↔ BannerSize?
getter/setter pair
webRetina ↔ BannerSize?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited