Location class

Annotations
  • @JsonSerializable.new(explicitToJson: true, fieldRename: FieldRename.snake)

Constructors

Location()
Location.fromJson(Map<String, dynamic> json)
factory

Properties

country ↔ String?
The country location for where the user that created the Tweet is from.
getter/setter pair
countryCode ↔ String?
A two-letter ISO-3166 country code that corresponds to the country location for where the user that created the Tweet is from.
getter/setter pair
fullName ↔ String?
The full name (excluding sub-region) for where the user that created the Tweet is from.
getter/setter pair
geo ↔ Coordinates?
An array that includes a lat/long value for a coordinate that corresponds to the lowers granularity location for where the user that created the Tweet is from.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locality ↔ String?
The locality location (generally city) for where the user that created the Tweet is from.
getter/setter pair
region ↔ String?
The region location (generally state/province) for where the user that created the Tweet is from.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subRegion ↔ String?
The sub-region location (generally county) for where the user that created the Tweet is from.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited